@@ -32,9 +32,10 @@
  *
  */
 
-#include "config.h"
+#include "squid.h"
 #include "base64.h"
 #include "ip/Address.h"
+#include "ip/tools.h"
 #include "rfc1123.h"
 #include "SquidTime.h"
 
@@ -210,7 +211,7 @@ main(int argc, char *argv[])
     int ping, pcount;
     int keep_alive = 0;
     int opt_noaccept = 0;
-    int opt_verbose = 0;
+    bool opt_verbose = false;
 #if HAVE_GSSAPI
     int www_neg = 0, proxy_neg = 0;
 #endif
@@ -246,6 +247,7 @@ main(int argc, char *argv[])
     pcount = 0;
     ping_int = 1 * 1000;
 
+    Ip::ProbeTransport(); // determine IPv4 or IPv6 capabilities before parsing.
     if (argc < 2) {
         usage(argv[0]);		/* need URL */
     } else if (argc >= 2) {
@@ -375,7 +377,7 @@ main(int argc, char *argv[])
 #endif
             case 'v':
                 /* undocumented: may increase verb-level by giving more -v's */
-                opt_verbose++;
+                opt_verbose=true;
                 break;
 
             case '?':		/* usage */
@@ -564,7 +566,7 @@ main(int argc, char *argv[])
     }
     loops = ping ? pcount : 1;
 
-    for (i = 0; loops == 0 || i < loops; i++) {
+    for (i = 0; loops == 0 || i < loops; ++i) {
         int fsize = 0;
         struct addrinfo *AI = NULL;
 
